@@ -12,7 +12,10 @@ from ..lnd import Lnd
 def test_lnd(lnd_dir):
     lnd = Lnd(lnd_dir=lnd_dir)
     assert lnd is not None
+    assert lnd.ln is not None
     assert lnd.lnrpc is not None
+    assert lnd.router is not None
+    assert lnd.routerrpc is not None
 
 
 @pytest.fixture
